@@ -299,7 +299,6 @@ int json_fill_system_status(char **ret) {
         _auto_cleanup_ char *mdns = NULL, *llmnr = NULL, *dns_over_tls = NULL, *conf_mode = NULL;
         _cleanup_(routing_policy_rules_freep) RoutingPolicyRules *rules = NULL;
         _cleanup_(links_freep) Links *links = NULL;
-        _auto_cleanup_strv_ char **ntp = NULL;
         _auto_cleanup_ DNSServer *c = NULL;
         sd_id128_t machine_id = {};
         sd_id128_t boot_id = {};
@@ -683,7 +682,6 @@ int json_fill_system_status(char **ret) {
 }
 
 int json_fill_dns_server(const IfNameIndex *p, int ifindex, json_object *jn) {
-        _cleanup_(dns_servers_freep) DNSServers *fallback = NULL, *dns = NULL;
         _cleanup_(json_object_putp) json_object *jobj = NULL, *jdns = NULL;
         int r;
 
@@ -711,7 +709,6 @@ int json_build_dns_server(const IfNameIndex *p, char **dns_config) {
         _cleanup_(dns_servers_freep) DNSServers *fallback = NULL, *dns = NULL;
         _cleanup_(json_object_putp) json_object *jobj = NULL, *jdns = NULL;
         _auto_cleanup_strv_ char **dhcp_dns = NULL;
-        _auto_cleanup_ DNSServer *current = NULL;
         _auto_cleanup_ char *provider = NULL;
         GSequenceIter *i;
         DNSServer *d;
@@ -810,7 +807,6 @@ int json_build_dns_server(const IfNameIndex *p, char **dns_config) {
 }
 
 static int json_parse_dns_search_domains(const json_object *jn, const char *link, json_object **ret) {
-        _cleanup_(json_object_putp) json_object *jdns = NULL;
         json_object *interfaces = NULL, *ifname = NULL;
 
         assert(jn);
@@ -825,7 +821,7 @@ static int json_parse_dns_search_domains(const json_object *jn, const char *link
                 if (!json_object_object_get_ex(interface, "Name", &ifname))
                         continue;
 
-                if (link && !str_eq(link, json_object_get_string(ifname)))
+                if (link && !streq(link, json_object_get_string(ifname)))
                         continue;
 
                 if (!json_object_object_get_ex(interface, "SearchDomains", &d))
@@ -1025,6 +1021,23 @@ int json_acquire_dns_mode(DHCPClient mode, bool dhcpv4, bool dhcpv6, bool static
         return 0;
 }
 
+int json_acquire_dhcp_mode(DHCPClient mode) {
+        _cleanup_(json_object_putp) json_object *jobj = NULL;
+        _cleanup_(json_object_putp) json_object *s = NULL;
+
+        jobj = json_object_new_object();
+        if (!jobj)
+                return log_oom();
+
+        s = json_object_new_string(dhcp_client_modes_to_name(mode));
+
+        json_object_object_add(jobj, "DHCPMode", s);
+        steal_ptr(s);
+
+        printf("%s\n", json_object_to_json_string_ext(jobj, JSON_C_TO_STRING_NOSLASHESCAPE | JSON_C_TO_STRING_SPACED | JSON_C_TO_STRING_PRETTY));
+        return 0;
+}
+
 int json_build_ntp_server(const IfNameIndex *p, json_object **ret) {
         _auto_cleanup_strv_ char **dhcp_ntp = NULL, **link_ntp = NULL, **ntp = NULL;
         _cleanup_(json_object_putp) json_object *jntp = NULL;
@@ -1047,7 +1060,6 @@ int json_build_ntp_server(const IfNameIndex *p, json_object **ret) {
         strv_foreach(n, link_ntp ? link_ntp : ntp) {
                 _cleanup_(json_object_putp) json_object *jaddr = NULL, *s = NULL;
                 _auto_cleanup_ IPAddress *a = NULL;
-                _auto_cleanup_ char *pretty = NULL;
 
                 jaddr = json_object_new_object();
                 if (!jaddr)
@@ -1190,7 +1202,7 @@ int json_fill_ntp_servers(const json_object *jn, const char *link, json_object *
                 if (!json_object_object_get_ex(interface, "Name", &ifname))
                         continue;
 
-                if (link && !str_eq(link, json_object_get_string(ifname)))
+                if (link && !streq(link, json_object_get_string(ifname)))
                         continue;
 
                 if (!json_object_object_get_ex(interface, "NTP", &ntp))
@@ -1295,7 +1307,7 @@ int json_parse_dns_servers(const json_object *jn, const char *link, json_object
                 if (!json_object_object_get_ex(interface, "Name", &ifname))
                         continue;
 
-                if (link && !str_eq(link, json_object_get_string(ifname)))
+                if (link && !streq(link, json_object_get_string(ifname)))
                         continue;
 
                 if (!json_object_object_get_ex(interface, "DNS", &dns))
@@ -1400,7 +1412,7 @@ int json_parse_address_config_source(const json_object *jobj,
                 json_object *interface = json_object_array_get_idx(interfaces, i);
                 json_object *name;
 
-                if (json_object_object_get_ex(interface, "Name", &name) && str_eq(json_object_get_string(name), link)) {
+                if (json_object_object_get_ex(interface, "Name", &name) && streq(json_object_get_string(name), link)) {
                         json_object *addresses = NULL;
 
                         if (!json_object_object_get_ex(interface, "Addresses", &addresses))
@@ -1418,7 +1430,7 @@ int json_parse_address_config_source(const json_object *jobj,
                                         if (r < 0)
                                                 continue;
 
-                                        if (str_eq(address, ip)) {
+                                        if (streq(address, ip)) {
                                                 if (json_object_object_get_ex(addr, "ConfigSource", &config_source)) {
                                                         *ret_config_source = strdup(json_object_get_string(config_source));
                                                         if (!*ret_config_source)
@@ -1474,7 +1486,7 @@ int json_parse_route_config_source(const json_object *jobj,
                 if (!json_object_object_get_ex(interface, "Name", &l))
                         continue;
 
-                if (!str_eq(link, json_object_get_string(l)))
+                if (!streq(link, json_object_get_string(l)))
                         continue;
 
                 if (!json_object_object_get_ex(interface, "Routes", &routes))
@@ -1491,7 +1503,7 @@ int json_parse_route_config_source(const json_object *jobj,
                                 if (r < 0)
                                         continue;
 
-                                if (str_eq(address, ip)) {
+                                if (streq(address, ip)) {
                                         if (json_object_object_get_ex(addr, "ConfigSource", &config_source)) {
                                                 *ret_config_source = strdup(json_object_get_string(config_source));
                                                 if (!*ret_config_source)
