@@ -40,7 +40,7 @@ int address_family_name_to_type(const char *name) {
         assert(name);
 
         for (size_t i = ADDRESS_FAMILY_NO; i < (size_t) ELEMENTSOF(address_family_table); i++)
-                if (str_eq_fold(name, address_family_table[i]))
+                if (streq_fold(name, address_family_table[i]))
                         return i;
 
         return _ADDRESS_FAMILY_INVALID;
@@ -67,7 +67,7 @@ int required_address_family_for_online_name_to_type(const char *name) {
         assert(name);
 
         for (size_t i = REQUIRED_ADDRESS_FAMILY_FOR_ONLINE_IPV4; i < (size_t) ELEMENTSOF(required_address_family_for_online_table); i++)
-                if (str_eq_fold(name, required_address_family_for_online_table[i]))
+                if (streq_fold(name, required_address_family_for_online_table[i]))
                         return i;
 
         return _ADDRESS_FAMILY_INVALID;
@@ -96,7 +96,7 @@ int device_activation_policy_name_to_type(const char *name) {
         assert(name);
 
         for (size_t i = DEVICE_ACTIVATION_POLICY_UP; i < (size_t) ELEMENTSOF(device_activation_policy_table); i++)
-                if (str_eq_fold(name, device_activation_policy_table[i]))
+                if (streq_fold(name, device_activation_policy_table[i]))
                         return i;
 
         return _DEVICE_ACTIVATION_POLICY_INVALID;
@@ -468,3 +468,54 @@ bool valid_duid(const char *p) {
 
         return true;
 }
+
+int parse_address_many(char **argv, int argc, int *i, char ***ret) {
+        _auto_cleanup_strv_ char **s = NULL;
+        bool white_space = false;
+        int r = -1;
+
+        if (strchr(argv[*i], ',')) {
+                char **d;
+
+                s = strsplit(argv[*i], ",", -1);
+                if (!s)
+                        return -EINVAL;
+
+                s = strv_remove(s, "");
+                if (!s)
+                        return -EINVAL;
+
+                strv_foreach(d, s) {
+                        _auto_cleanup_ IPAddress *a = NULL;
+
+                        r = parse_ip_from_str(*d, &a);
+                        if (r < 0)
+                                return r;
+                }
+
+        } else {
+                _auto_cleanup_strv_ char **t = NULL;
+                char **d;
+
+                r = argv_to_strv(argc - 4, argv + *i, &t);
+                if (r < 0)
+                        return r;
+
+                strv_foreach(d, t) {
+                        _auto_cleanup_ IPAddress *a = NULL;
+
+                        r = parse_ip_from_str(*d, &a);
+                        if (r >= 0) {
+                                strv_extend(&s, *d);
+                                (*i)++;
+                        }
+                }
+                white_space = true;
+        }
+
+        *ret = steal_ptr(s);
+        if (white_space)
+                (*i)--;
+
+        return 0;
+}
