@@ -54,7 +54,7 @@ int conf_type_to_mode(const char *name) {
         assert(name);
 
         for (size_t i = CONF_TYPE_MATCH; i < (size_t) ELEMENTSOF(conf_type_table); i++)
-                if (str_eq_fold(name, conf_type_table[i]))
+                if (streq_fold(name, conf_type_table[i]))
                         return i;
 
         return _CONF_TYPE_INVALID;
@@ -377,14 +377,14 @@ int parse_yaml_dhcp_type(const char *key,
 
         n = data;
 
-        if (str_eq("dhcp4", key)) {
+        if (streq("dhcp4", key)) {
                 r = parse_bool(value);
                 if (r < 0)
                         return r;
 
                 n->dhcp4 = r;
 
-        } else if (str_eq("dhcp6", key)) {
+        } else if (streq("dhcp6", key)) {
                 r = parse_bool(value);
                 if (r < 0)
                         return r;
@@ -654,7 +654,7 @@ int parse_yaml_addresses(const char *key,
         for (yaml_node_item_t *i = node->data.sequence.items.start; i < node->data.sequence.items.top; i++) {
                 yaml_node_t *entry = yaml_document_get_node(doc, *i);
 
-                if (str_eq("addresses", key)) {
+                if (streq("addresses", key)) {
                         r = parse_address_from_str_and_add(scalar(entry), network->addresses);
                         if (r < 0 && r != -EEXIST)
                                 return r;
@@ -818,13 +818,13 @@ int parse_yaml_route(const char *key,
 
         rt = data;
 
-        if (str_eq("to", key) || str_eq("via", key)) {
+        if (streq("to", key) || streq("via", key)) {
                 _auto_cleanup_ IPAddress *address = NULL;
                 bool b = false;
 
                 r = parse_ip_from_str(value, &address);
                 if (r < 0) {
-                        if (str_eq("default", value))
+                        if (streq("default", value))
                                 b = true;
                         else {
                                 log_warning("Failed to parse %s='%s'", key, value);
@@ -832,10 +832,10 @@ int parse_yaml_route(const char *key,
                         }
                 }
 
-                if (str_eq("0.0.0.0/0", value) || str_eq("::/0", value))
+                if (streq("0.0.0.0/0", value) || streq("::/0", value))
                         b = true;
 
-                if (str_eq("to", key)) {
+                if (streq("to", key)) {
                         if (address) {
                                 rt->dst = *address;
                                 rt->family = address->family;
@@ -928,9 +928,9 @@ int parse_yaml_vxlan_notifications(const char *key,
         for (yaml_node_item_t *i = node->data.sequence.items.start; i < node->data.sequence.items.top; i++) {
                 yaml_node_t *entry = yaml_document_get_node(doc, *i);
 
-                if (str_eq(scalar(entry), "l2-miss"))
+                if (streq(scalar(entry), "l2-miss"))
                         v->l2miss = true;
-                else if (str_eq(scalar(entry), "l3-miss"))
+                else if (streq(scalar(entry), "l3-miss"))
                         v->l3miss = true;
         }
 
@@ -957,17 +957,17 @@ int parse_yaml_vxlan_csum(const char *key,
         for (yaml_node_item_t *i = node->data.sequence.items.start; i < node->data.sequence.items.top; i++) {
                 yaml_node_t *entry = yaml_document_get_node(doc, *i);
 
-                if (str_eq(scalar(entry), "udp"))
+                if (streq(scalar(entry), "udp"))
                         v->udpcsum = true;
-                else if (str_eq(scalar(entry), "zero-udp6-tx"))
+                else if (streq(scalar(entry), "zero-udp6-tx"))
                         v->udp6zerocsumtx = true;
-                else if (str_eq(scalar(entry), "zero-udp6-rx"))
+                else if (streq(scalar(entry), "zero-udp6-rx"))
                         v->udp6zerocsumrx = true;
-                else if (str_eq(scalar(entry), "zero-udp6-tx"))
+                else if (streq(scalar(entry), "zero-udp6-tx"))
                         v->udp6zerocsumtx = true;
-                else if (str_eq(scalar(entry), "remote-tx"))
+                else if (streq(scalar(entry), "remote-tx"))
                         v->remote_csum_tx = true;
-                else if (str_eq(scalar(entry), "remote-rx"))
+                else if (streq(scalar(entry), "remote-rx"))
                         v->remote_csum_rx = true;
         }
 
@@ -994,9 +994,9 @@ int parse_yaml_vxlan_extensions(const char *key,
         for (yaml_node_item_t *i = node->data.sequence.items.start; i < node->data.sequence.items.top; i++) {
                 yaml_node_t *entry = yaml_document_get_node(doc, *i);
 
-                if (str_eq(scalar(entry), "group-policy"))
+                if (streq(scalar(entry), "group-policy"))
                         v->group_policy = true;
-                else if (str_eq(scalar(entry), "generic-protocol"))
+                else if (streq(scalar(entry), "generic-protocol"))
                         v->generic_protocol_extension = true;
         }
 
@@ -1226,7 +1226,7 @@ int parse_yaml_wireguard_key_or_path(const char *key,
 
         w = (WireGuard *) data;
 
-        if (str_eq(key, "key")) {
+        if (streq(key, "key")) {
                 if (string_has_prefix(value, "/")) {
                         w->private_key_file = strdup(value);
                         if (!w->private_key_file)
@@ -1263,7 +1263,7 @@ int parse_yaml_sequence_wireguard_peer_shared_key_or_path(const char *key,
                 k = yaml_document_get_node(doc, *i++);
                 v = yaml_document_get_node(doc, *i);
 
-                if (str_eq(scalar(k), "shared")) {
+                if (streq(scalar(k), "shared")) {
                         if (string_has_prefix(value, "/")) {
                                 w->preshared_key_file = strdup(scalar(v));
                                 if (!w->preshared_key_file)
@@ -1273,7 +1273,7 @@ int parse_yaml_sequence_wireguard_peer_shared_key_or_path(const char *key,
                                 if (!w->preshared_key)
                                         return log_oom();
                         }
-                } else if (str_eq(scalar(k), "public")) {
+                } else if (streq(scalar(k), "public")) {
                         w->public_key = strdup(scalar(v));
                         if (!w->public_key)
                                 return log_oom();
